@@ -31,85 +31,14 @@
 
 #include <qfile.h>
 
-#ifdef Q_OS_WIN
-# include <windows.h>
-#else
-# include <unistd.h>
-# include <cerrno>
-#endif
-
-#ifndef Q_OS_WIN
-# define STD_OUTPUT_HANDLE 1
-# define STD_ERROR_HANDLE 2
-#endif
-
-#ifdef _WIN32_WCE
-#include <stdio.h>
-#endif
-
-void KProcessPrivate::writeAll(const QByteArray &buf, int fd)
-{
-#ifdef Q_OS_WIN
-#ifndef _WIN32_WCE
-    HANDLE h = GetStdHandle(fd);
-    if (h) {
-        DWORD wr;
-        WriteFile(h, buf.data(), buf.size(), &wr, 0);
-    }
-#else
-    fwrite(buf.data(), 1, buf.size(), (FILE*)fd);
-#endif
-#else
-    int off = 0;
-    do {
-        int ret = ::write(fd, buf.data() + off, buf.size() - off);
-        if (ret < 0) {
-            if (errno != EINTR)
-                return;
-        } else {
-            off += ret;
-        }
-    } while (off < buf.size());
-#endif
-}
-
-void KProcessPrivate::forwardStd(KProcess::ProcessChannel good, int fd)
-{
-    Q_Q(KProcess);
-
-    QProcess::ProcessChannel oc = q->readChannel();
-    q->setReadChannel(good);
-    writeAll(q->readAll(), fd);
-    q->setReadChannel(oc);
-}
-
-void KProcessPrivate::_k_forwardStdout()
-{
-#ifndef _WIN32_WCE
-    forwardStd(KProcess::StandardOutput, STD_OUTPUT_HANDLE);
-#else
-    forwardStd(KProcess::StandardOutput, (int)stdout);
-#endif
-}
-
-void KProcessPrivate::_k_forwardStderr()
-{
-#ifndef _WIN32_WCE
-    forwardStd(KProcess::StandardError, STD_ERROR_HANDLE);
-#else
-    forwardStd(KProcess::StandardError, (int)stderr);
-#endif
-}
-
 /////////////////////////////
 // public member functions //
 /////////////////////////////
 
 KProcess::KProcess(QObject *parent) :
     QProcess(parent),
-    d_ptr(new KProcessPrivate)
+    d_ptr(new KProcessPrivate(this))
 {
-    d_ptr->q_ptr = this;
     setOutputChannelMode(ForwardedChannels);
 }
 
@@ -121,37 +50,16 @@ KProcess::KProcess(KProcessPrivate *d, QObject *parent) :
     setOutputChannelMode(ForwardedChannels);
 }
 
-KProcess::~KProcess()
-{
-    delete d_ptr;
-}
+KProcess::~KProcess() = default;
 
 void KProcess::setOutputChannelMode(OutputChannelMode mode)
 {
-    Q_D(KProcess);
-
-    d->outputChannelMode = mode;
-    disconnect(this, SIGNAL(readyReadStandardOutput()));
-    disconnect(this, SIGNAL(readyReadStandardError()));
-    switch (mode) {
-    case OnlyStdoutChannel:
-        connect(this, SIGNAL(readyReadStandardError()), SLOT(_k_forwardStderr()));
-        break;
-    case OnlyStderrChannel:
-        connect(this, SIGNAL(readyReadStandardOutput()), SLOT(_k_forwardStdout()));
-        break;
-    default:
-        QProcess::setProcessChannelMode((ProcessChannelMode)mode);
-        return;
-    }
-    QProcess::setProcessChannelMode(QProcess::SeparateChannels);
+    QProcess::setProcessChannelMode(static_cast<ProcessChannelMode>(mode));
 }
 
 KProcess::OutputChannelMode KProcess::outputChannelMode() const
 {
-    Q_D(const KProcess);
-
-    return d->outputChannelMode;
+    return static_cast<OutputChannelMode>(QProcess::processChannelMode());
 }
 
 void KProcess::setNextOpenMode(QIODevice::OpenMode mode)
@@ -381,7 +289,7 @@ int KProcess::startDetached()
     qint64 pid;
     if (!QProcess::startDetached(d->prog, d->args, workingDirectory(), &pid))
         return 0;
-    return (int) pid;
+    return static_cast<int>(pid);
 }
 
 // static
@@ -390,7 +298,7 @@ int KProcess::startDetached(const QString &exe, const QStringList &args)
     qint64 pid;
     if (!QProcess::startDetached(exe, args, QString(), &pid))
         return 0;
-    return (int) pid;
+    return static_cast<int>(pid);
 }
 
 // static
@@ -400,13 +308,3 @@ int KProcess::startDetached(const QStringList &argv)
     QString prog = args.takeFirst();
     return startDetached(prog, args);
 }
-
-int KProcess::pid() const
-{
-#ifdef Q_OS_UNIX
-    return (int) QProcess::pid();
-#else
-    return QProcess::pid() ? QProcess::pid()->dwProcessId : 0;
-#endif
-}
-
